@@ -19,6 +19,11 @@ pub struct Build {
     #[serde(default = "default::target")]
     pub target: PathBuf,
 
+    /// The name of the output HTML file.
+    ///
+    /// If not set, use the same name as the target HTML file.
+    pub html_output: Option<String>,
+
     /// Build in release mode [default: false]
     #[serde(default)]
     pub release: bool,
@@ -71,6 +76,11 @@ pub struct Build {
     #[serde(default = "default::filehash")]
     pub filehash: bool,
 
+    /// Whether to build an example.
+    #[serde(default)]
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub example: Option<String>,
+
     /// Optional pattern for the app loader script [default: None]
     ///
     /// Patterns should include the sequences `{base}`, `{wasm}`, and `{js}` in order to
@@ -141,6 +151,14 @@ pub struct Build {
     /// are sure it is caused due to a false positive.
     #[serde(default)]
     pub allow_self_closing_script: bool,
+
+    /// Create 'nonce' attributes with a placeholder.
+    #[serde(default)]
+    pub create_nonce: bool,
+
+    /// The placeholder which is used in the 'nonce' attribute.
+    #[serde(default = "default::nonce_placeholder")]
+    pub nonce_placeholder: String,
 }
 
 fn string_or_vec<'de, T, D>(deserializer: D) -> Result<Vec<T>, D::Error>
@@ -189,6 +207,7 @@ impl Default for Build {
     fn default() -> Self {
         Self {
             target: default::target(),
+            html_output: None,
             release: false,
             cargo_profile: None,
             dist: default::dist(),
@@ -200,6 +219,7 @@ impl Default for Build {
             no_default_features: false,
             all_features: false,
             features: vec![],
+            example: None,
             filehash: default::filehash(),
             pattern_script: None,
             inject_scripts: default::inject_scripts(),
@@ -210,6 +230,8 @@ impl Default for Build {
             minify: Default::default(),
             no_sri: false,
             allow_self_closing_script: false,
+            create_nonce: false,
+            nonce_placeholder: default::nonce_placeholder(),
         }
     }
 }
@@ -233,6 +255,10 @@ mod default {
     pub const fn inject_scripts() -> bool {
         true
     }
+
+    pub fn nonce_placeholder() -> String {
+        "{{__TRUNK NONCE__}}".to_string()
+    }
 }
 
 mod schema {
