@@ -23,7 +23,7 @@ use crate::{
     tools::{self, Application, ToolInformation},
 };
 use anyhow::{anyhow, bail, ensure, Context, Result};
-use cargo_metadata::Artifact;
+use cargo_metadata::{Artifact, TargetKind};
 use minify_js::TopLevelMode;
 use seahash::SeaHasher;
 use std::{
@@ -420,6 +420,10 @@ impl RustApp {
             args.push("--bin");
             args.push(bin);
         }
+        if let Some(example) = &self.cfg.cargo_example {
+            args.push("--example");
+            args.push(example);
+        }
 
         match &self.cargo_features {
             Features::All => args.push("--all-features"),
@@ -818,13 +822,22 @@ impl RustApp {
             return false;
         }
 
-        // must be cdylib or bin
-        if !(art.target.kind.contains(&"bin".to_string())
-            || art.target.kind.contains(&"cdylib".to_string()))
+        // must be cdylib, bin, or example
+        if !(art.target.kind.contains(&TargetKind::Bin)
+            || art.target.kind.contains(&TargetKind::CDyLib)
+            || art.target.kind.contains(&TargetKind::Example))
         {
             return false;
         }
 
+        // Are we building an example?
+        if let Some(example) = &self.cfg.cargo_example {
+            // it must match
+            if example != &art.target.name {
+                return false;
+            }
+        }
+
         // if we have the --bin argument
         if let Some(bin) = &self.bin {
             // it must match
