@@ -1,6 +1,6 @@
 mod proxy;
 
-use crate::common::{LOCAL, NETWORK, SERVER};
+use crate::common::{nonce, LOCAL, NETWORK, SERVER};
 use crate::config::rt::RtcServe;
 use crate::tls::TlsConfig;
 use crate::watch::WatchSystem;
@@ -17,6 +17,7 @@ use axum::routing::{get, get_service, Router};
 use axum_server::Handle;
 use futures_util::FutureExt;
 use hickory_resolver::TokioAsyncResolver;
+use http::header::CONTENT_SECURITY_POLICY;
 use http::HeaderMap;
 use proxy::{ProxyBuilder, ProxyClientOptions};
 use std::collections::{BTreeSet, HashMap, HashSet};
@@ -130,7 +131,7 @@ impl ServeSystem {
         let state = Arc::new(State::new(
             cfg.watch.build.final_dist.clone(),
             serve_base_url.to_string(),
-            &cfg,
+            cfg.clone(),
             ws_state,
         )?);
         let router = router(state, cfg.clone())?;
@@ -342,6 +343,8 @@ pub struct State {
     pub ws_base: String,
     /// Additional headers to add to responses.
     pub headers: HashMap<String, String>,
+    /// Configuration
+    pub cfg: Arc<RtcServe>,
 }
 
 impl State {
@@ -349,7 +352,7 @@ impl State {
     pub fn new(
         dist_dir: PathBuf,
         serve_base: String,
-        cfg: &RtcServe,
+        cfg: Arc<RtcServe>,
         ws_state: watch::Receiver<ws::State>,
     ) -> Result<Self> {
         let mut ws_base = cfg.ws_base()?.to_string();
@@ -363,6 +366,7 @@ impl State {
             ws_state,
             ws_base,
             headers: cfg.headers.clone(),
+            cfg,
         })
     }
 }
@@ -482,6 +486,12 @@ async fn html_address_middleware(
     // split into parts and body
     let (parts, body) = response.into_parts();
 
+    let nonce = state
+        .cfg
+        .create_nonce
+        .as_ref()
+        .map(|p| (p.as_str(), nonce()));
+
     // turn the body into bytes
     match axum::body::to_bytes(body, 100 * 1024 * 1024).await {
         Err(err) => {
@@ -501,12 +511,32 @@ async fn html_address_middleware(
                         .and_then(|uri| uri.to_str().map(|s| format!("'{}'", s)).ok())
                         .unwrap_or_else(|| "window.location.host".into());
 
-                    let data_str = data_str
+                    let mut data_str = data_str
                         // minification will turn quotes into backticks, so we have to replace both
                         .replace("'{{__TRUNK_ADDRESS__}}'", &host)
                         .replace("`{{__TRUNK_ADDRESS__}}`", &host)
                         // here we only replace the string value
                         .replace("{{__TRUNK_WS_BASE__}}", &state.ws_base);
+
+                    let mut csp = None;
+
+                    if let Some((var, val)) = nonce {
+                        data_str = data_str.replace(var, &val);
+                        csp = state
+                            .cfg
+                            .csp
+                            .as_ref()
+                            .map(|csp| csp.join(";").replace("{{NONCE}}", &val).parse());
+                    }
+
+                    match csp {
+                        Some(Ok(csp)) => {
+                            parts.headers.insert(CONTENT_SECURITY_POLICY, csp);
+                        }
+                        Some(Err(e)) => tracing::error!("failed to encode csp header: {e:?}"),
+                        None => {}
+                    };
+
                     let bytes_vec = data_str.as_bytes().to_vec();
                     parts.headers.insert(CONTENT_LENGTH, bytes_vec.len().into());
                     bytes = Bytes::from(bytes_vec);
